
from kotonebot.tasks.common import sprite_path
from kotonebot.backend.core import Image, HintBox, HintPoint



class Common:
    
    ButtonClose = Image(path=sprite_path(r"53767d10-de15-4a37-bb01-e3e7d4dd7369.png"), name="button_close.png")

    ButtonCommuFastforward = Image(path=sprite_path(r"9936687a-0d42-42e5-86c3-c9b763c71349.png"), name="button_commu_fastforward.png")

    ButtonCommuSkip = Image(path=sprite_path(r"a6277a84-1f69-48ea-947c-8bcfb4fbff5d.png"), name="button_commu_skip.png")

    ButtonCompletion = Image(path=sprite_path(r"5b53cf72-ceaa-4942-b0ef-36252611e2b8.png"), name="button_completion.png")

    ButtonConfirm = Image(path=sprite_path(r"fa399da0-48f4-4b02-8517-06e12718e0f9.png"), name="button_confirm.png")

    ButtonConfirmNoIcon = Image(path=sprite_path(r"07b1cae5-62b8-433b-8664-bdd06ee1f888.png"), name="button_confirm_no_icon.png")

    ButtonContest = Image(path=sprite_path(r"e89f1b01-b824-45f0-83eb-1429ce9292c2.png"), name="button_contest.png")

    ButtonEnd = Image(path=sprite_path(r"3b8a2fc5-4819-47b0-abaa-bd494db26557.png"), name="button_end.png")

    ButtonHome = Image(path=sprite_path(r"71b8f502-0a26-4092-9153-e8f01369dffb.png"), name="button_home.png")

    ButtonIconArrowShort = Image(path=sprite_path(r"e04666a1-21a0-47ad-be5f-a45a2e0f3a38.png"), name="button_icon_arrow_short.png")

    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"74bc812f-ce6c-4282-b0b6-0a856a9e5857.png"), name="button_icon_arrow_short_disabled.png")

    ButtonIconCheckMark = Image(path=sprite_path(r"20d91648-5c1b-4d9c-8246-e57d192205f8.png"), name="button_icon_check_mark.png")

    ButtonIconClose = Image(path=sprite_path(r"0ed9be06-d64f-413b-bf95-4c7af846f4c0.png"), name="button_icon_close.png")

    ButtonNext = Image(path=sprite_path(r"f1941b63-91e8-4e95-9baf-22591fb069b6.png"), name="button_next.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"58d48082-cc32-4f7a-8043-f4df6fe86d57.png"), name="button_next_no_icon.png")

    ButtonRetry = Image(path=sprite_path(r"ac233ed9-510c-4e61-a5c2-c7adb46c396f.png"), name="button_retry.png")

    ButtonSelect = Image(path=sprite_path(r"cfc950cd-73a0-48da-8ca1-5646198c6367.png"), name="button_select.png")

    ButtonStart = Image(path=sprite_path(r"be0129fb-bad3-466f-99da-ca9943a88290.png"), name="button_start.png")

    ButtonToolbarHome = Image(path=sprite_path(r"893531e1-acca-4315-a3d1-54ef8bb5ea2a.png"), name="button_toolbar_home.png")

    CheckboxUnchecked = Image(path=sprite_path(r"8945d0f1-7c9e-453a-afbf-2340f877f5bb.png"), name="checkbox_unchecked.png")

    ButtonToolbarHomeBinary = Image(path=sprite_path(r"2f68e457-4491-4ebc-b436-e3e63db92e14.png"), name="底部工具栏 首页按钮 二值化图片")

    ButtonToolbarMenuBinary = Image(path=sprite_path(r"bf6dcf21-2ffc-441f-82f3-59319f2313b1.png"), name="底部工具栏 菜单按钮 二值化图片")

    TextGameUpdate = Image(path=sprite_path(r"fb6dc05f-137f-4a8a-acb2-f19df80b6cf8.png"), name="text_game_update.png")

    TextNetworkError = Image(path=sprite_path(r"2609aa4e-074c-457c-a929-685388448507.png"), name="text_network_error.png")

    ButtonOK = Image(path=sprite_path(r"8424ecdd-8857-4764-9fd0-d4bfa440c128.png"), name="OK 按钮")

    ButtonSelect2 = Image(path=sprite_path(r"5ebcde3b-f0fd-4e5d-b3de-ada8f0b5e03b.png"), name="選択する")


    pass
class Daily:
    
    ButonLinkData = Image(path=sprite_path(r"f6a831e2-fc2e-4aa8-9556-813ad00190bd.png"), name="buton_link_data.png")

    ButtonAssignmentPartial = Image(path=sprite_path(r"9251fba9-1261-4609-9ee6-b076af040c85.png"), name="button_assignment_partial.png")

    ButtonClaimAllNoIcon = Image(path=sprite_path(r"5502d190-eaaa-400a-adba-10fb14ae9e85.png"), name="button_claim_all_no_icon.png")

    ButtonContestChallenge = Image(path=sprite_path(r"e99ebceb-7a23-48b3-9299-04e6c05a0212.png"), name="button_contest_challenge.png")

    ButtonContestChallengeStart = Image(path=sprite_path(r"0367df59-c66f-4bb0-9971-a4a6523987ec.png"), name="button_contest_challenge_start.png")

    ButtonContestRanking = Image(path=sprite_path(r"3f4042e9-a4af-4983-83eb-e97a38aea1fa.png"), name="button_contest_ranking.png")

    ButtonContestStart = Image(path=sprite_path(r"073e4e34-3ba1-4db6-8588-10ebc4634beb.png"), name="button_contest_start.png")

    ButtonDailyShop = Image(path=sprite_path(r"adab1848-3915-4b95-9db9-562f23c1395e.png"), name="button_daily_shop.png")

    ButtonHomeCurrent = Image(path=sprite_path(r"930cd051-4955-4664-9d75-28753db2ae78.png"), name="button_home_current.png")

    ButtonIconPass = Image(path=sprite_path(r"37534f18-6795-44fe-9ae1-345a0f241515.png"), name="button_icon_pass.png")

    ButtonIconSkip = Image(path=sprite_path(r"54d4d6c0-da23-48ce-8492-473cf2d100fa.png"), name="button_icon_skip.png")

    ButtonMission = Image(path=sprite_path(r"ddd980a8-f935-4132-b2d7-7a71ca6f8662.png"), name="button_mission.png")

    ButtonPass = Image(path=sprite_path(r"7152f752-0e7d-4989-baf7-5b340cef128b.png"), name="button_pass.png")

    ButtonPassClaim = Image(path=sprite_path(r"f30ed3e4-492d-4673-ab60-b02ee2763455.png"), name="button_pass_claim.png")

    ButtonPresentsPartial = Image(path=sprite_path(r"8dffe5ab-c790-4b90-8835-032e9b6631b5.png"), name="button_presents_partial.png")

    ButtonProduce = Image(path=sprite_path(r"e8156e32-bd80-430c-b5c2-7ff30a64f0f3.png"), name="button_produce.png")

    ButtonShop = Image(path=sprite_path(r"c7d282d4-d996-4c90-8adf-9a1c6976e51d.png"), name="button_shop.png")

    ButtonShopCountAdd = Image(path=sprite_path(r"fe9a2bbf-7ff0-4ad7-80bb-979a9a8ebcae.png"), name="button_shop_count_add.png")

    ButtonShopCountAddDisabled = Image(path=sprite_path(r"325f8fe1-67c0-4913-b762-8011ea52e589.png"), name="button_shop_count_add_disabled.png")

    IconTitleDailyShop = Image(path=sprite_path(r"e9ee330d-dfca-440e-8b8c-0a3b4e8c8730.png"), name="日常商店标题图标")

    BoxHomeAssignment = HintBox(x1=16, y1=642, x2=127, y2=752, source_resolution=(720, 1280))

    BoxHomeAP = HintBox(x1=291, y1=4, x2=500, y2=82, source_resolution=(720, 1280))

    BoxHomeJewel = HintBox(x1=500, y1=7, x2=703, y2=82, source_resolution=(720, 1280))

    BoxHomeActivelyFunds = HintBox(x1=11, y1=517, x2=137, y2=637, source_resolution=(720, 1280))

    IconAssignKouchou = Image(path=sprite_path(r"c0939da0-a603-432d-b69e-4dcef392e4ec.png"), name="icon_assign_kouchou.png")

    IconAssignMiniLive = Image(path=sprite_path(r"be3156df-0702-4aba-9eab-d5c91a915c70.png"), name="icon_assign_mini_live.png")

    IconAssignOnlineLive = Image(path=sprite_path(r"6f2005f1-c713-4472-b513-a4e9aa7c9c1e.png"), name="icon_assign_online_live.png")

    IconAssignTitle = Image(path=sprite_path(r"4c0abfdb-dd0d-44e1-a2f8-4f1acfaa5e5f.png"), name="icon_assign_title.png")

    IconShopAp = Image(path=sprite_path(r"5a7b42a3-f5c8-48f8-a0a8-e1edeb2ae4a7.png"), name="icon_shop_ap.png")

    IconShopMoney = Image(path=sprite_path(r"c7c54269-f970-4c31-a2ab-e54327321c05.png"), name="icon_shop_money.png")

    IconShopTitle = Image(path=sprite_path(r"c704e720-4b84-410e-9c26-96d35ad1c5f5.png"), name="icon_shop_title.png")

    IconTitleAssign = Image(path=sprite_path(r"cee42603-d213-41bf-8134-19733ee21dea.png"), name="icon_title_assign.png")

    IconTitlePass = Image(path=sprite_path(r"dfee3fe1-731e-45f4-9f8f-3eb3622869a5.png"), name="icon_title_pass.png")

    BoxApkUpdateDialogTitle = HintBox(x1=26, y1=905, x2=342, y2=967, source_resolution=(720, 1280))

    ButtonAssignmentShortenTime = Image(path=sprite_path(r"1652f06a-5417-49ef-8949-4854772d9ab7.png"), name="工作页面 短缩 时间")

    BoxMissonTabs = HintBox(x1=11, y1=929, x2=703, y2=1030, source_resolution=(720, 1280))

    TextActivityFundsMax = Image(path=sprite_path(r"0f27b452-55bd-4532-944b-68284c9ac0e3.png"), name="text_activity_funds_max.png")

    TextAssignmentCompleted = Image(path=sprite_path(r"9abbbcee-8b11-4a8e-baa2-5fb0d8d63ed6.png"), name="text_assignment_completed.png")

    TextContest = Image(path=sprite_path(r"5fd62c63-5ca5-44ab-80cb-5ce75267e8e8.png"), name="text_contest.png")

    TextContestLastOngoing = Image(path=sprite_path(r"4e88f3e3-3333-46e9-bc1a-d6ab4837dbb2.png"), name="text_contest_last_ongoing.png")

    TextContestNoMemory = Image(path=sprite_path(r"d4c209d8-73be-4530-a3db-e1576d60a334.png"), name="text_contest_no_memory.png")

    TextContestOverallStats = Image(path=sprite_path(r"1bb0f21a-35bd-4543-b701-7197ebf94d48.png"), name="text_contest_overall_stats.png")

    TextShopPurchased = Image(path=sprite_path(r"5315226e-39f2-45ce-9ea2-e84bb4a4da19.png"), name="text_shop_purchased.png")

    TextShopRecommended = Image(path=sprite_path(r"c446af29-4f6c-4898-b656-36ff0e0af450.png"), name="text_shop_recommended.png")

    TextTabShopAp = Image(path=sprite_path(r"d4d15c22-9136-4bd4-b841-7cc556f305c5.png"), name="text_tab_shop_ap.png")


    pass
class Shop:
    
    ItemLessonNote = Image(path=sprite_path(r"0949c622-9067-4f0d-bac2-3f938a1d2ed2.png"), name="レッスンノート")

    ItemVeteranNote = Image(path=sprite_path(r"b2af59e9-60e3-4d97-8c72-c7ba092113a3.png"), name="ベテランノート")

    ItemSupportEnhancementPt = Image(path=sprite_path(r"835489e2-b29b-426c-b4c9-3bb9f8eb6195.png"), name="サポート強化Pt 支援强化Pt")

    ItemSenseNoteVocal = Image(path=sprite_path(r"c5b7d67e-7260-4f08-a0e9-4d31ce9bbecf.png"), name="センスノート（ボーカル）感性笔记（声乐）")

    ItemSenseNoteDance = Image(path=sprite_path(r"0f7d581d-cea3-4039-9205-732e4cd29293.png"), name="センスノート（ダンス）感性笔记（舞蹈）")

    ItemSenseNoteVisual = Image(path=sprite_path(r"d3cc3323-51af-4882-ae12-49e7384b746d.png"), name="センスノート（ビジュアル）感性笔记（形象）")

    ItemLogicNoteVocal = Image(path=sprite_path(r"a1df3af1-a3e7-4521-a085-e4dc3cd1cc57.png"), name="ロジックノート（ボーカル）理性笔记（声乐）")

    ItemLogicNoteDance = Image(path=sprite_path(r"a9fcaf04-0c1f-4b0f-bb5b-ede9da96180f.png"), name="ロジックノート（ダンス）理性笔记（舞蹈）")

    ItemLogicNoteVisual = Image(path=sprite_path(r"c3f536d6-a04a-4651-b3f9-dd2c22593f7f.png"), name="ロジックノート（ビジュアル）理性笔记（形象）")

    ItemAnomalyNoteVocal = Image(path=sprite_path(r"eef25cf9-afd0-43b1-b9c5-fbd997bd5fe0.png"), name="アノマリーノート（ボーカル）非凡笔记（声乐）")

    ItemAnomalyNoteDance = Image(path=sprite_path(r"df991b42-ed8e-4f2c-bf0c-aa7522f147b6.png"), name="アノマリーノート（ダンス）非凡笔记（舞蹈）")

    ItemAnomalyNoteVisual = Image(path=sprite_path(r"9340b854-025c-40da-9387-385d38433bef.png"), name="アノマリーノート（ビジュアル）非凡笔记（形象）")

    ItemRechallengeTicket = Image(path=sprite_path(r"ea1ba124-9cb3-4427-969a-bacd47e7d920.png"), name="再挑戦チケット 重新挑战券")

    ItemRecordKey = Image(path=sprite_path(r"1926f2f9-4bd7-48eb-9eba-28ec4efb0606.png"), name="記録の鍵  解锁交流的物品")

    class IdolPiece:
        
        倉本千奈_WonderScale = Image(path=sprite_path(r"6720b6e8-ae80-4cc0-a885-518efe12b707.png"), name="倉本千奈 WonderScale 碎片")
    
        篠泽广_光景 = Image(path=sprite_path(r"afa06fdc-a345-4384-b25d-b16540830256.png"), name="篠泽广 光景 碎片")
    
        紫云清夏_TameLieOneStep = Image(path=sprite_path(r"278b7d9c-707e-4392-9677-74574b5cdf42.png"), name="紫云清夏 Tame-Lie-One-Step 碎片")
    
        葛城リーリヤ_白線 = Image(path=sprite_path(r"74ff07b3-d91c-4579-80cd-379ed7020622.png"), name="葛城リーリヤ 白線 碎片")
    
        姫崎薪波_cIclumsy_trick  = Image(path=sprite_path(r"a7f5abf1-982f-4a55-8d41-3ad6f56798e0.png"), name="姫崎薪波 cIclumsy trick 碎片")
    
        花海咲季_FightingMyWay = Image(path=sprite_path(r"2bc00520-0afe-40e5-8743-d33fc6b2945a.png"), name="花海咲季 FightingMyWay 碎片")
    
        藤田ことね_世界一可愛い私 = Image(path=sprite_path(r"135ee57a-d30d-4ba8-83f0-9f1681a49ff7.png"), name="藤田ことね 世界一可愛い私 碎片")
    
        花海佑芽_TheRollingRiceball = Image(path=sprite_path(r"d15959bf-d07b-4f07-948a-c0aeaf17756a.png"), name="花海佑芽 The Rolling Riceball 碎片")
    
        月村手毬_LunaSayMaybe = Image(path=sprite_path(r"868b97a9-492e-4712-b47f-82b97495b019.png"), name="月村手毬 Luna say maybe 碎片")
    
    
        pass

    pass
class Produce:
    
    BoxProduceOngoing = HintBox(x1=179, y1=937, x2=551, y2=1091, source_resolution=(720, 1280))

    ButtonAutoSet = Image(path=sprite_path(r"0b8fbd86-019e-4393-bd51-aa6ccea963b6.png"), name="button_auto_set.png")

    ButtonProduce = Image(path=sprite_path(r"5dc3991a-0bbb-40c6-97c4-16f6868606f6.png"), name="button_produce.png")

    ButtonProduceStart = Image(path=sprite_path(r"2fd3efbc-a6cb-4627-956e-834703ff21cd.png"), name="button_produce_start.png")

    ButtonRegular = Image(path=sprite_path(r"4a5a28eb-c0cb-4e45-9491-e4d8a93fcf69.png"), name="button_regular.png")

    CheckboxIconNoteBoost = Image(path=sprite_path(r"dd0a4897-1d71-4453-8fff-a04b38f85acd.png"), name="checkbox_icon_note_boost.png")

    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"33e1e5b7-825f-42c7-9827-0c434bd0f779.png"), name="checkbox_icon_support_pt_boost.png")

    BoxModeButtons = HintBox(x1=7, y1=818, x2=713, y2=996, source_resolution=(720, 1280))

    ButtonPIdolOverview = Image(path=sprite_path(r"e88c9ad1-ec37-4fcd-b086-862e1e7ce8fd.png"), name="Pアイドルー覧  P偶像列表展示")

    BoxStepIndicator = HintBox(x1=4, y1=11, x2=405, y2=99, source_resolution=(720, 1280))

    BoxSetCountIndicator = HintBox(x1=17, y1=671, x2=119, y2=707, source_resolution=(720, 1280))

    PointProduceNextSet = HintPoint(x=702, y=832)

    PointProducePrevSet = HintPoint(x=14, y=832)

    IconPIdolLevel = Image(path=sprite_path(r"30a6f399-6999-4f04-bb77-651e0214112f.png"), name="P偶像卡上的等级图标")

    KbIdolOverviewName = HintBox(x1=140, y1=16, x2=615, y2=97, source_resolution=(720, 1280))

    ButtonResume = Image(path=sprite_path(r"ccbcb114-7f73-43d1-904a-3a7ae660c531.png"), name="再開する")

    BoxResumeDialogProduceType = HintBox(x1=186, y1=491, x2=541, y2=550, source_resolution=(720, 1280))

    BoxResumeDialogIdolTitle = HintBox(x1=194, y1=794, x2=523, y2=840, source_resolution=(720, 1280))

    RadioTextSkipCommu = Image(path=sprite_path(r"2362497c-0bbd-49a0-b063-cf5f621fcaa7.png"), name="radio_text_skip_commu.png")

    TextAPInsufficient = Image(path=sprite_path(r"4883c564-f950-4a29-9f5f-6f924123cd22.png"), name="培育 AP 不足提示弹窗 标题")

    ButtonRefillAP = Image(path=sprite_path(r"eaba6ebe-f0df-4918-aee5-ef4e3ffedcf0.png"), name="确认恢复AP按钮")

    ScreenshotNoEnoughAp2 = Image(path=sprite_path(r"fa50dc3b-9c5a-4753-a3cd-4b24a2757f18.png"), name="screenshot_no_enough_ap_2.png")

    TextRentAvailable = Image(path=sprite_path(r"4e275b9b-0090-4b6d-8345-dff73454c88c.png"), name="text_rent_available.png")


    pass
class InPurodyuusu:
    
    A = Image(path=sprite_path(r"0dc43d9b-570f-4a96-bdd5-9dcae3186cb9.png"), name="A.png")

    AcquireBtnDisabled = Image(path=sprite_path(r"925deb28-5887-4214-a74d-cc9a2ef26e6b.png"), name="acquire_btn_disabled.png")

    ButtonCancel = Image(path=sprite_path(r"a4cb52b9-ad38-4b58-9c08-0f33b868fc26.png"), name="button_cancel.png")

    ButtonComplete = Image(path=sprite_path(r"674f8747-b6d5-4db8-ab78-777e57de225b.png"), name="button_complete.png")

    ButtonFinalPracticeDance = Image(path=sprite_path(r"3b26a5e9-c0f5-4cc0-af0d-e907323c0eb0.png"), name="button_final_practice_dance.png")

    ButtonFinalPracticeVisual = Image(path=sprite_path(r"ebb06ceb-e80c-4a4c-956f-d7ce42d43562.png"), name="button_final_practice_visual.png")

    ButtonFinalPracticeVocal = Image(path=sprite_path(r"ef3ea0c3-b1d6-4ab4-8156-599ebfc41bb1.png"), name="button_final_practice_vocal.png")

    ButtonFollowNoIcon = Image(path=sprite_path(r"0cbfee83-229b-4902-a472-ec486f5eed80.png"), name="button_follow_no_icon.png")

    ButtonIconStudy = Image(path=sprite_path(r"570896e0-31b3-4f09-8891-c44550427d21.png"), name="button_icon_study.png")

    ButtonIconStudyVisual = Image(path=sprite_path(r"63d4974a-abff-42d0-acca-292747691a19.png"), name="button_icon_study_visual.png")

    ButtonLeave = Image(path=sprite_path(r"43c04b40-eee6-44b9-b4e3-0921e59b5f65.png"), name="button_leave.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"e5b65a0f-3251-46cf-823c-f4010d3c6fab.png"), name="button_next_no_icon.png")

    ButtonNotAcquire = Image(path=sprite_path(r"8dd8cf52-6012-41cd-9983-fe42a2e0b928.png"), name="button_not_acquire.png")

    ButtonRetry = Image(path=sprite_path(r"a0f60e5f-a944-44ea-8b8a-a935129928bd.png"), name="button_retry.png")

    ButtonTextActionOuting = Image(path=sprite_path(r"4a9469db-597d-4ba9-b4a9-45f39eb8c7c8.png"), name="button_text_action_outing.png")

    ButtonTextAllowance = Image(path=sprite_path(r"6389d8ff-610a-4770-99ae-88b810c89b40.png"), name="button_text_allowance.png")

    ButtonTextConsult = Image(path=sprite_path(r"1843857e-9771-45ea-8f2a-8e5a5a67cca4.png"), name="button_text_consult.png")

    IconClearBlue = Image(path=sprite_path(r"8538e047-7e74-40b2-b00f-e5620da92968.png"), name="icon_clear_blue.png")

    IconTitleAllowance = Image(path=sprite_path(r"95a41e2b-7408-466f-93d3-93a7a5912aec.png"), name="icon_title_allowance.png")

    IconTitleStudy = Image(path=sprite_path(r"1fe8ae52-c3ea-4ed6-8f31-f6c8ffdac620.png"), name="icon_title_study.png")

    LootboxSliverLock = Image(path=sprite_path(r"48758513-496b-41ce-9257-89088d80a747.png"), name="lootbox_sliver_lock.png")

    LootBoxSkillCard = Image(path=sprite_path(r"a11c14e3-7c32-4519-bf8c-238500c069b9.png"), name="loot_box_skill_card.png")

    M = Image(path=sprite_path(r"d51f87b5-a8ad-42c3-855b-f86e78664dc1.png"), name="M.png")

    BoxWeeksUntilExam = HintBox(x1=11, y1=8, x2=237, y2=196, source_resolution=(720, 1280))

    TextActionVocal = Image(path=sprite_path(r"d6b64759-26b7-45b1-bf8e-5c0d98611e0d.png"), name="Vo. レッスン")

    TextActionDance = Image(path=sprite_path(r"303cccc1-c674-4d3a-8c89-19ea729fdbef.png"), name="Da. レッスン")

    TextActionVisual = Image(path=sprite_path(r"cc8a495d-330d-447d-8a80-a8a6ecc409c5.png"), name="Vi. レッスン")

    BoxExamTop = HintBox(x1=5, y1=2, x2=712, y2=55, source_resolution=(720, 1280))

    PDrinkIcon = Image(path=sprite_path(r"d096837f-3a85-4261-91b8-f5d5b6389420.png"), name="p_drink_icon.png")

    PItemIconColorful = Image(path=sprite_path(r"8fbcbbe4-240f-437a-850a-78ef9858da3e.png"), name="p_item_icon_colorful.png")

    PSkillCardIconBlue = Image(path=sprite_path(r"4351a2b2-2f14-4f98-83b1-fccbd458a549.png"), name="p_skill_card_icon_blue.png")

    PSkillCardIconColorful = Image(path=sprite_path(r"4d9a4619-aa8c-49bb-97ee-5aa091323294.png"), name="p_skill_card_icon_colorful.png")

    Rest = Image(path=sprite_path(r"f5d8a71f-81d9-454a-99a9-efe292bf083a.png"), name="rest.png")

    RestConfirmBtn = Image(path=sprite_path(r"43aa0c40-0ee0-409a-a185-fd2fef3b24d7.png"), name="rest_confirm_btn.png")

    ButtonIconOuting = Image(path=sprite_path(r"8ded6c98-85ea-4858-a66d-4fc8caecb7c5.png"), name="行动按钮图标 外出（おでかけ）")

    BoxGoalClearNext = HintBox(x1=79, y1=503, x2=157, y2=532, source_resolution=(720, 1280))

    BoxLessonCards5_1 = HintBox(x1=16, y1=882, x2=208, y2=1136, source_resolution=(720, 1280))

    BoxNoSkillCard = HintBox(x1=180, y1=977, x2=529, y2=1026, source_resolution=(720, 1280))

    TitleIconOuting = Image(path=sprite_path(r"ee4e512b-4982-49b6-9c71-31984b58e1d0.png"), name="外出（おでかけ）页面 标题图标")

    BoxPDrinkMaxConfirmTitle = HintBox(x1=46, y1=829, x2=270, y2=876, source_resolution=(720, 1280))

    BoxSelectPStuff = HintBox(x1=62, y1=558, x2=655, y2=716, source_resolution=(720, 1280))

    BoxSelectPStuffComfirm = HintBox(x1=256, y1=1064, x2=478, y2=1128, source_resolution=(720, 1280))

    BoxSkillCardAcquired = HintBox(x1=194, y1=712, x2=528, y2=765, source_resolution=(720, 1280))

    BoxSkillCardEnhaced = HintBox(x1=49, y1=948, x2=676, y2=1106, source_resolution=(720, 1280))

    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"a1237a18-f67e-47e9-8c0f-3eee780ee3cf.png"), name="screenshot_skill_card_enhance_dialog.png")

    IconTitleSkillCardEnhance = Image(path=sprite_path(r"79abd239-5eed-4195-9fa8-d729daa874ca.png"), name="技能卡强化 标题 图标")

    ButtonEnhance = Image(path=sprite_path(r"da439e8c-3b74-4371-9657-0736d826c7d1.png"), name="技能卡 强化按钮")

    T = Image(path=sprite_path(r"16fbc93d-b294-4001-b4e9-ee2af181415f.png"), name="睡意卡字母 T（眠気）")

    IconSp = Image(path=sprite_path(r"d982d2b5-4bc0-4ae9-a516-f29c2848d64b.png"), name="SP 课程图标")

    BoxCommuEventButtonsArea = HintBox(x1=14, y1=412, x2=703, y2=1089, source_resolution=(720, 1280))

    TextSelfStudyVocal = Image(path=sprite_path(r"c78c38cc-7b61-4dc4-820d-0a5b684ef52e.png"), name="文化课事件 自习 声乐")

    TextSelfStudyDance = Image(path=sprite_path(r"83d0a033-466c-463a-bb8c-be0f2953e9b2.png"), name="文化课事件 自习 舞蹈")

    TextSelfStudyVisual = Image(path=sprite_path(r"4695f96b-c4f5-4bb6-a021-a13b6ceb2883.png"), name="文化课事件 自习 形象")

    TextAsariProduceEnd = Image(path=sprite_path(r"2046839b-79c1-4a59-b537-fd8eb01d7827.png"), name="text_asari_produce_end.png")

    TextButtonExamSkipTurn = Image(path=sprite_path(r"6788029b-c00c-43b2-900e-b3fa44c6a69d.png"), name="text_button_exam_skip_turn.png")

    TextClearUntil = Image(path=sprite_path(r"ef527c48-8bc3-43c9-9847-9d61297c4812.png"), name="text_clear_until.png")

    TextDance = Image(path=sprite_path(r"381437a1-61ed-4f61-8503-8be2f7924637.png"), name="text_dance.png")

    TextFinalProduceRating = Image(path=sprite_path(r"cd3cbea0-045a-4a1c-849a-8fe1019c01aa.png"), name="text_final_produce_rating.png")

    TextOneWeekRemaining = Image(path=sprite_path(r"71593ff3-1019-4002-9f8b-62192343ff13.png"), name="text_one_week_remaining.png")

    TextPerfectUntil = Image(path=sprite_path(r"4daaf8c3-0b99-4f73-8f4e-812939967b00.png"), name="text_perfect_until.png")

    TextPleaseSelectPDrink = Image(path=sprite_path(r"e148cfe1-8a7a-47c7-94b3-97359ab6745d.png"), name="text_please_select_p_drink.png")

    TextPDiary = Image(path=sprite_path(r"1447953f-dddf-4809-8ddd-14fbe72ad636.png"), name="text_p_diary.png")

    TextPDrinkMax = Image(path=sprite_path(r"438a341c-2ede-4a4c-8413-800cd90a3505.png"), name="text_p_drink_max.png")

    TextSenseiTipConsult = Image(path=sprite_path(r"78edfdb0-4075-4e71-985d-07d14b1a280a.png"), name="text_sensei_tip_consult.png")

    TextSenseiTipDance = Image(path=sprite_path(r"095e7a92-01f7-406a-a705-aebc9607ee00.png"), name="text_sensei_tip_dance.png")

    TextSenseiTipRest = Image(path=sprite_path(r"e3ecbdf1-5673-4d58-bd96-2683074c8270.png"), name="text_sensei_tip_rest.png")

    TextSenseiTipVisual = Image(path=sprite_path(r"b5038d3d-e6ea-4c6e-a727-7d44c471a9a8.png"), name="text_sensei_tip_visual.png")

    TextSenseiTipVocal = Image(path=sprite_path(r"a832950c-9344-445e-8fc8-e05d14ac80d7.png"), name="text_sensei_tip_vocal.png")

    TextSkipTurnDialog = Image(path=sprite_path(r"bdfcfa1a-0586-4aeb-a607-26a3a5d08984.png"), name="text_skip_turn_dialog.png")

    TextVisual = Image(path=sprite_path(r"94403972-f449-49ee-a294-8eefbde47d47.png"), name="text_visual.png")

    class Action:
        
        ActionStudy = Image(path=sprite_path(r"22910b8c-a379-4424-88be-7ab529bd576a.png"), name="action_study.png")
    
        PDorinkuBg = Image(path=sprite_path(r"b501f432-5a61-4dba-a5b6-06a686e6f8c6.png"), name="p_dorinku_bg.png")
    
        PDorinkuBgMask = Image(path=sprite_path(r"d344eca0-eb27-4c02-8d2a-d7344dd02305.png"), name="p_dorinku_bg_mask.png")
    
        PItem = Image(path=sprite_path(r"99940e5a-6e98-438f-8874-f81f01efa0a0.png"), name="p_item.png")
    
        VocalWhiteBg = Image(path=sprite_path(r"3498fade-032d-4a44-8197-5dfc4c43d460.png"), name="vocal_white_bg.png")
    
    
        pass

    pass